﻿
var $fb = {

    /**
    * Facebook application ID
    */
    appId: '156296394403385',

    /**
    * Login permissions
    */
    permissions: 'publish_stream, read_stream, user_checkins, user_likes, user_events, offline_access',

    /**
    * Canvas dimentions for iframe application page
    */
    canvasHeight: 1200,
    canvasWidth: 760,

    /**
    * Locale used to localize Facebook UI
    */
    locale: 'en_US',

    /**
    * Initialized facebook SDK
    */
    init: function () {
        $fb.log('init: initializing FB javascript SDK')

        // creates script tag for Facebook SDK
        var protocol = document.location.protocol;
        protocol = (protocol.indexOf("file") < 0) ? protocol : "http:";
        var e = document.createElement('script');
        e.async = true;
        e.src = protocol + '//connect.facebook.net/' + $fb.locale + '/all.js';
        document.getElementById('fb-root').appendChild(e);
    },

    /**
    * Prints to console
    */
    fbAsyncInitComplete: function () {
        $fb.log('fbAsyncInitComplete: initialization complete');
        FB.Canvas.setSize({ width: $fb.canvasWidth, height: $fb.canvasHeight });
    },

    /**
    * Stores the application session
    */
    session: {},

    /**
    * Etablishes a connection to Facebook
    */
    connect: function (perms) {
        $fb.log('connect: getting login status');

        if (perms != "") $fb.permissions = perms;

        $fb.log('permissions: ' + $fb.permissions);

        FB.getLoginStatus(function (response) {

            // check if logged in to Facebook
            if (response.status) {
                $fb.log('user is logged in');

                // check if logged into application
                if (response.session) {
                    $fb.log('user is logged into application');
                    $fb.session = response.session;
                    $fb.onConnectComplete();
                }
                else {
                    $fb.log('user is not logged into application');
                    $fb.login();
                }
            }
            else {
                $fb.log('user is not logged in');
                $fb.login();
            }
        });
    },

    getLoginStatus: function () {
        FB.getLoginStatus(function (response) {

            var status = '';

            // check if logged in to Facebook
            if (response.status) {
                $fb.log('user is logged in');
                status = "LoggedIn";
            }
            else {
                $fb.log('user is not logged in');
                status = "LoggedOut";
            }

            $fb.onLoginStatusRecieved(status);
        });
    },

    onLoginStatusRecieved: function (status) {

        $fb.log('onLoginStatusRecieved: ' + status);
    },

    /**
    * Prompts user to log in
    */
    login: function () {
        $fb.log('login: attempting to log user in')
        FB.login(function (response) {
            if (response.session) {
                $fb.log('login: user successfully logged in');
                $fb.session = response.session;
                $fb.onConnectComplete();
            } else {
                $fb.log('login: user cancelled login');
            }
        }, { perms: $fb.permissions });
    },

    /**
    * FB connecting complete handler
    */
    onConnectComplete: function () {
        $fb.log('connectComplete: connection with facebook established');
    },

    /**
    * Retrieves access token
    */
    getAccessToken: function () {
        return $fb.session.access_token;
    },

    /**
    * Prompts a user to publish to stream 
    */
    streamPublish: function (data) {
        $fb.log("streamPublish: attempting to publish to user stream");

        // check JSON data
        if (!data) {
            data = {
                method: 'stream.publish',
                display: "popup",
                message: 'Enter your message here.',
                attachment: {
                    name: 'Stream Publish',
                    caption: 'This is a stream publish caption.',
                    description: 'This is a stream publish description.',
                    media: [{
                        type: 'image',
                        src: 'http://www.seeklogo.com/images/A/AKQA-logo-7297446D44-seeklogo.com.gif',
                        href: 'http://www.akqa.com'
                    }],

                    href: 'http://www.akqa.com'
                }
            };
        }

        // open UI for user
        FB.ui(data, function (response) {
            if (response && response.post_id) $fb.onStreamPublishOk(response);
            else $fb.onStreamPublishCancel();
        });
    },

    /**
    * Stream publish success
    */
    onStreamPublishOk: function () {
        $fb.log("streamPublish: ok");
    },

    /**
    * Stream publish was canceled
    */
    onStreamPublishCancel: function () {
        $fb.log("streamPublish: cancel");
    },

    /**
    * Prints to console
    */
    log: function (ob) {
        try {
            console.log('[Facebook] ' + ob);
        } catch (e) {
            //
        }
    }
}

window.fbAsyncInit = function () {
    FB.init({
        appId: $fb.appId,
        status: true,
        cookie: true,
        xfbml: true
    });

    $fb.fbAsyncInitComplete();
};